[evolution-data-server/openismus-work-master: 85/150] Changes for Review: EBookSortType renamed to EBookCursorSortType



commit 72a0c250d9e768e544d4d64f95aa6ff4828cceae
Author: Tristan Van Berkom <tristanvb openismus com>
Date:   Sat Oct 5 01:58:44 2013 +0200

    Changes for Review: EBookSortType renamed to EBookCursorSortType

 .../libebook-contacts/e-book-contacts-types.h      |   12 ++++++------
 1 files changed, 6 insertions(+), 6 deletions(-)
---
diff --git a/addressbook/libebook-contacts/e-book-contacts-types.h 
b/addressbook/libebook-contacts/e-book-contacts-types.h
index 535ae07..0d7c54d 100644
--- a/addressbook/libebook-contacts/e-book-contacts-types.h
+++ b/addressbook/libebook-contacts/e-book-contacts-types.h
@@ -136,16 +136,16 @@ typedef enum {
 } EBookIndexType;
 
 /**
  * EBookSortType:
  * @E_BOOK_SORT_ASCENDING: Sort results in ascending order
  * @E_BOOK_SORT_DESCENDING: Sort results in descending order
  *
  * Specifies the sort order of an ordered query
  */
 typedef enum {
-       E_BOOK_SORT_ASCENDING = 0,
-       E_BOOK_SORT_DESCENDING
-} EBookSortType;
+       E_BOOK_CURSOR_SORT_ASCENDING = 0,
+       E_BOOK_CURSOR_SORT_DESCENDING
+} EBookCursorSortType;
 
 /**
  * EBookCursorOrigin:
@@ -136,16 +136,16 @@ typedef enum {
 
 /**
- * EBookSortType:
- * @E_BOOK_SORT_ASCENDING: Sort results in ascending order
- * @E_BOOK_SORT_DESCENDING: Sort results in descending order
+ * EBookCursorSortType:
+ * @E_BOOK_CURSOR_SORT_ASCENDING: Sort results in ascending order
+ * @E_BOOK_CURSOR_SORT_DESCENDING: Sort results in descending order
  *
  * Specifies the sort order of an ordered query


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]